// This extension was developed by :
// * Mark Bokil http://markbokil.com
// * http://markbokil.com/downloads/extensions/lookingglass
// version: 1.0
// date: 8-25-12
// Licence: GPLv2+

const St = imports.gi.St;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Util = imports.misc.util;
const Main = imports.ui.main;
const Lang = imports.lang;
const GLib = imports.gi.GLib;
const Shell = imports.gi.Shell;
const Gettext = imports.gettext;
const _ = Gettext.domain('lookingglass').gettext;

// LookingGlass function
function LookingGlass(metadata)
{	
	let locales = metadata.path + "/locale";
	Gettext.bindtextdomain('lookingglass', locales);

	this._init();
}

// Prototype
LookingGlass.prototype =
{
	__proto__: PanelMenu.Button.prototype,
	
    	_init: function(gicon) 
    	{			
		PanelMenu.Button.prototype._init.call(this, St.Align.START);

		this._iconActor = new St.Icon({ icon_name: 'utilities-terminal-symbolic',
                                   		icon_type: St.IconType.SYMBOLIC,
                                        style_class: 'system-status-icon' });

        this.actor.add_actor(this._iconActor); 
		this._iconActor.get_parent().add_style_class_name("panelButtonWidth");
			
		this._buildMenu();
	},
	
	_buildMenu: function()
	{    			
		// looking glass
		this.lg = new PopupMenu.PopupMenuItem("Looking Glass");
		this.menu.addMenuItem(this.lg);
		this.lg.connect('activate', Lang.bind(this, this._onLookingGlass));

		// reload theme
		this.reloadTheme = new PopupMenu.PopupMenuItem("Reload Theme");
		this.menu.addMenuItem(this.reloadTheme);
		this.reloadTheme.connect('activate', Lang.bind(this, this._onReloadTheme));

		this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());

		// restart
		this.restart = new PopupMenu.PopupMenuItem("Restart Shell");
		this.menu.addMenuItem(this.restart);
		this.restart.connect('activate', Lang.bind(this, this._onRestart));
		
	},

	_onLookingGlass: function() {
		Main.createLookingGlass().toggle();
	},

	_onReloadTheme: function() {
		Util.spawnCommandLine(Main.loadTheme());
	},

	_onRestart: function() {
		Util.spawnCommandLine(global.reexec_self());
	},

	enable: function()
	{
		Main.panel._rightBox.insert_child_at_index(this.actor, 0);
		Main.panel._menus.addMenu(this.menu);
	},

	disable: function()
	{
		Main.panel._menus.removeMenu(this.menu);
		Main.panel._rightBox.remove_actor(this.actor);
	}
}
	

// Init function
function init(metadata) 
{		
	return new LookingGlass(metadata);
}
